pub enum JobContent {
DicomMoveScu {
description: CompactString,
local_aet: CompactString,
query: Vec<MoveScuJobQuery>,
remote_aet: CompactString,
target_aet: CompactString,
},
DicomModalityStore {},
OrthancPeerStore {
compress: bool,
description: CompactString,
failed_instances_count: usize,
instances_count: usize,
parent_resources: Vec<String>,
peer: [CompactString; 3],
size: u64,
},
ResourceModification(ResourceModificationContent),
MergeStudy {},
SplitStudy {},
StorageCommitmentScp {},
}Expand description
The content of an Orthanc job.
WARNING: not all variants are implemented, check the source code.
Job type ref: https://orthanc.uclouvain.be/hg/orthanc/file/Orthanc-1.12.8/OrthancServer/Sources/ServerJobs/OrthancJobUnserializer.cpp#l66
Variants
DicomMoveScu
DICOM MOVE-SCU job.
Fields

description: CompactString
local_aet: CompactString
query: Vec<MoveScuJobQuery>
remote_aet: CompactString
target_aet: CompactStringDicomModalityStore
OrthancPeerStore
Store DICOM in peer Orthanc job.
Fields

description: CompactString
parent_resources: Vec<String>Local resource IDs being pushed to the peer. Note that the resource type is not known, it might be a patient, study, series, or instance.

peer: [CompactString; 3]peer configuration.
ResourceModification(ResourceModificationContent)
MergeStudy
SplitStudy
StorageCommitmentScp